require 'net/https'
require 'uri'
require 'trollop'
class PortalsAPI
  attr_accessor :access_token

  PORTALS_HOST = 'https://portal2-beta.instructure.com/'.freeze
  PORTALS_USER = 'rkuss2'.freeze

  def initialize(portal_access_token)
    @access_token = portal_access_token
  end

  def retrieve_portal_status(portals_host = PORTALS_HOST, portals_user = PORTALS_USER)
    portal_endpoint = portals_host + 'canvas/isStarted/' + portals_user
    get_request(portal_endpoint).body
  end

  def start_stop_portal(portals_host = PORTALS_HOST, portals_user = PORTALS_USER)
    portal_endpoint = portals_host + 'canvas/startStopPortal/' + portals_user
    get_request(portal_endpoint).body
  end

  def retrieve_checkedout_patchset(portals_host = PORTALS_HOST, portals_user = PORTALS_USER)
    portal_endpoint = portals_host + 'canvas/isCheckedOut/' + portals_user
    get_request(portal_endpoint).body
  end

  def checkout_patchset(patchset_name = 'master', dbcreate = false,
    portals_host = PORTALS_HOST, portals_user = PORTALS_USER)
    portal_endpoint = portals_host + 'canvas/checkoutPatchset?user=' + portals_user + '&patchset=' + patchset_name
    portal_endpoint += '&db_created=0' if dbcreate
    get_request(portal_endpoint).body
  end

  def cancel_portal_request(portals_host = PORTALS_HOST, portals_user = PORTALS_USER)
    portal_endpoint = portals_host + 'canvas/cancelRequest?user=' + portals_user
    get_request(portal_endpoint).body
  end

  private

  def get_request(endpoint)
    uri = URI.parse(endpoint)
    http = Net::HTTP.new(uri.host, uri.port)
    http.use_ssl = true
    http.verify_mode = OpenSSL::SSL::VERIFY_NONE

    request = Net::HTTP::Get.new(uri.request_uri)
    request['Access_token'] = @access_token
    http.request(request)
  end
end
